@@ -90,9 +90,9 @@ class scanner(object):
         This returns a status stream, which only delivers updates when the device has changed.
         Do not use this in a synchronous blocking call. Use the `get_status` method instead.
 
-        :returns: :py:class:`blickfeld_scanner.scanner.status_stream` object
+        :returns: :py:class:`blickfeld_scanner.scanner.stream.status` object
         """
-        return status_stream(self.create_connection())
+        return stream.status(self.create_connection())
 
     def get_point_cloud_stream(self, filter=None, reference_frame=None, point_filter=None):
         """ Request point cloud stream of device
@@ -212,6 +212,21 @@ class scanner(object):
         req.get_scan_pattern.SetInParent()
         return self._connection.send_request(req).get_scan_pattern.config
     
+    def get_scan_pattern_constraints(self):
+        """This request returns a list of constraints which are applied on scan patterns.
+        
+        > Introduced in BSL v2.14 and firmware v1.14
+        
+        The constraints define the constant and dynamic relationships between field values.
+        The constraints are equal for a device type and firmware, but might vary for firmware releases and device variants.
+        It is mainly used to visualize the constraints in the scan pattern configuration of the web gui.
+
+        :return: List of active constraints, see :any:`protobuf_protocol` common
+        """
+        req = connection_pb2.Request()
+        req.get_scan_pattern_constraints.SetInParent()
+        return self._connection.send_request(req).get_scan_pattern_constraints.constraints
+    
     def set_advanced_config(self, config, persist = False):
         """ Function to set advanced config, see: :any:`protobuf_protocol`.
         Expert parameters: It is not recommended to adapt this calibrated configuration without understanding the influences on the resulting point cloud quality.
@@ -501,33 +516,3 @@ class connection(object):
         """
         if hasattr(self, "socket"):
             self.socket.close()
-
-
-
-class status_stream(object):
-    """Class to request a status stream
-
-    :param connection: connection to the device
-    :type connection: :py:class:`blickfeld_scanner.scanner.connection`
-    """
-    def __init__(self, connection):
-        self._connection = connection
-
-        req = connection_pb2.Request()
-        req.subscribe.status.SetInParent()
-        ret = self._connection.send_request(req)
-
-    def __del__(self):
-        self.close()
-
-    def close(self):
-        """ Close stream and connection
-        """
-        self._connection.close()
-
-    def recv_status(self):
-        """ Receive status update
-
-        :return: Status messages of the device, see: :any:`protobuf_protocol`
-        """
-        return self._connection.recv().event.status
